@@ -20,7 +20,23 @@ def __dump_json__(file_path, json):
 
 
 def __convert_str_to_list(value):
-    return value.strip("][").split(',')
+    value = value.strip("][").split(',')
+    new_value = []
+    for i in value:
+        new_value.append(__parse_type_and_value__(i.strip(), start_block='<<', end_block='>>'))
+    return new_value
+
+
+def __parse_type_and_value__(parse_value: str, start_block: str = '<', end_block: str = '>') -> int | str | bool:
+    types = {"int": int, "list": __convert_str_to_list, "str": str, "None": str, None: str, "bool": bool}
+    parse = re.search(fr"(.*){start_block}(\w+){end_block}", parse_value)
+    if parse:
+        value = parse.group(1)
+        type_value = parse.group(2)
+    else:
+        value = parse_value
+        type_value = None
+    return types[type_value](value)
 
 
 def __wait_confirmation__(message: str) -> bool:
@@ -60,7 +76,6 @@ def create_command(params):
     """
     Функция создания конфига из шаблона
     """
-    # TODO: сделать чтение конфига лога из шаблона
     with open(params.template_config) as template_file:
         template = json_load(template_file.read())
 
@@ -73,16 +88,12 @@ def create_command(params):
     config = __parse_template__(template)
 
     if params.extra_vars:
-        types = {"<int>": int, "<list>": __convert_str_to_list, "<str>": str, "None": str, None: str, "<bool>": bool}
         for i in params.extra_vars:
             path, value = i.split("=")
             path = path.split('/')
-            type_value = re.search(r"<\w+>", value)
-            value = value.split("<")[0]
-            if type_value:
-                type_value = type_value.group(0)
+            value = __parse_type_and_value__(value)
             element = __walk_on_json_path__("/".join(path[:-1]), config, config)
-            element[path[-1]] = types[type_value](value)
+            element[path[-1]] = value
 
     __dump_json__(params.config_file, config)
     print('Конфигурация создана')
